@@ -49,8 +49,8 @@ def setUpAvatar(gender: str):
         avatar_properties['friction'] = 'human'
         avatar_properties['body_resolution'] = 'normal'
         avatar_properties['hair_style'] = 'Adam_m_Natural Fling.3ds'
-        avatar_properties['skin_tone'] = '25.mat'
-        # avatar_properties['skin_tone'] = 'mannequin\\\\White-Matt.mat'
+        # avatar_properties['skin_tone'] = '25.mat'
+        avatar_properties['skin_tone'] = 'mannequin\\\\White-Matt.mat'
         BwApi.AvatarPropertiesUpdate(json.dumps(avatar_properties))
         # BwApi.AvatarPropertiesUpdate(json.dumps(loadJson('avatar_properties.json')))
         BwApi.AvatarPoseCurrentSet("Model01", 0, 0)
@@ -61,8 +61,9 @@ def setUpAvatar(gender: str):
         avatar_properties['friction'] = 'human'
         avatar_properties['body_resolution'] = 'normal'
         avatar_properties['hair_style'] = 'Deborah_f_Sassy blonde.3ds'
-        avatar_properties['skin_tone'] = '25.mat'
+        # avatar_properties['skin_tone'] = '25.mat'
         # avatar_properties['skin_tone'] = 'mannequin\\White-Matt.mat'
+        avatar_properties['skin_tone'] = 'mannequin\\Bright gray.mat'
         BwApi.AvatarPropertiesUpdate(json.dumps(avatar_properties))
         BwApi.AvatarPoseCurrentSet("Casual01b", 0, 0)
 
